package com.muyu.product.service.impl;

import java.util.List;
import com.muyu.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.muyu.product.mapper.AttributeGroupMapper;
import com.muyu.product.domain.AttributeGroup;
import com.muyu.product.service.IAttributeGroupService;

/**
 * 属性组Service业务层处理
 *
 * @author muyu
 * @date 2024-02-29
 */
@Service
public class AttributeGroupServiceImpl implements IAttributeGroupService
{
    @Autowired
    private AttributeGroupMapper attributeGroupMapper;

    /**
     * 查询属性组
     *
     * @param id 属性组主键
     * @return 属性组
     */
    @Override
    public AttributeGroup selectAttributeGroupById(Long id)
    {
        return attributeGroupMapper.selectAttributeGroupById(id);
    }

    /**
     * 查询属性组列表
     *
     * @param attributeGroup 属性组
     * @return 属性组
     */
    @Override
    public List<AttributeGroup> selectAttributeGroupList(AttributeGroup attributeGroup)
    {
        return attributeGroupMapper.selectAttributeGroupList(attributeGroup);
    }

    /**
     * 新增属性组
     *
     * @param attributeGroup 属性组
     * @return 结果
     */
    @Override
    public int insertAttributeGroup(AttributeGroup attributeGroup)
    {
        attributeGroup.setCreateTime(DateUtils.getNowDate());
        return attributeGroupMapper.insertAttributeGroup(attributeGroup);
    }

    /**
     * 修改属性组
     *
     * @param attributeGroup 属性组
     * @return 结果
     */
    @Override
    public int updateAttributeGroup(AttributeGroup attributeGroup)
    {
        attributeGroup.setUpdateTime(DateUtils.getNowDate());
        return attributeGroupMapper.updateAttributeGroup(attributeGroup);
    }

    /**
     * 批量删除属性组
     *
     * @param ids 需要删除的属性组主键
     * @return 结果
     */
    @Override
    public int deleteAttributeGroupByIds(Long[] ids)
    {
        return attributeGroupMapper.deleteAttributeGroupByIds(ids);
    }

    /**
     * 删除属性组信息
     *
     * @param id 属性组主键
     * @return 结果
     */
    @Override
    public int deleteAttributeGroupById(Long id)
    {
        return attributeGroupMapper.deleteAttributeGroupById(id);
    }
}
